---
title: <span class="badge builder"></span> YAxisConfig
---
# <span class="badge builder"></span> YAxisConfig

## Constructor

```python
YAxisConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.YAxisConfig
```

### <span class="badge object-method"></span> axis_border_show

```python
def axis_border_show(axis_border_show: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_centered_zero

```python
def axis_centered_zero(axis_centered_zero: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_color_mode

```python
def axis_color_mode(axis_color_mode: common.AxisColorMode) -> typing.Self
```

### <span class="badge object-method"></span> axis_grid_show

```python
def axis_grid_show(axis_grid_show: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_label

```python
def axis_label(axis_label: str) -> typing.Self
```

### <span class="badge object-method"></span> axis_placement

```python
def axis_placement(axis_placement: common.AxisPlacement) -> typing.Self
```

### <span class="badge object-method"></span> axis_soft_max

```python
def axis_soft_max(axis_soft_max: float) -> typing.Self
```

### <span class="badge object-method"></span> axis_soft_min

```python
def axis_soft_min(axis_soft_min: float) -> typing.Self
```

### <span class="badge object-method"></span> axis_width

```python
def axis_width(axis_width: float) -> typing.Self
```

### <span class="badge object-method"></span> decimals

Controls the number of decimals for yAxis values

```python
def decimals(decimals: float) -> typing.Self
```

### <span class="badge object-method"></span> max_val

Sets the maximum value for the yAxis

```python
def max_val(max_val: float) -> typing.Self
```

### <span class="badge object-method"></span> min_val

Sets the minimum value for the yAxis

```python
def min_val(min_val: float) -> typing.Self
```

### <span class="badge object-method"></span> reverse

Reverses the yAxis

```python
def reverse(reverse: bool) -> typing.Self
```

### <span class="badge object-method"></span> scale_distribution

```python
def scale_distribution(scale_distribution: cogbuilder.Builder[common.ScaleDistributionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> unit

Sets the yAxis unit

```python
def unit(unit: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [YAxisConfig](./object-YAxisConfig.md)
